[med-svn] r1492 - trunk/community/infrastructure/scripts

tille at alioth.debian.org tille at alioth.debian.org
Sat Mar 1 14:09:12 UTC 2008


Author: tille
Date: 2008-03-01 14:09:12 +0000 (Sat, 01 Mar 2008)
New Revision: 1492

Modified:
   trunk/community/infrastructure/scripts/cddtasktools.py
   trunk/community/infrastructure/scripts/update-tasks
Log:
THe '&' is actually %26 and not %3F ...


Modified: trunk/community/infrastructure/scripts/cddtasktools.py
===================================================================
--- trunk/community/infrastructure/scripts/update-tasks	2008-03-01 14:02:29 UTC (rev 1491)
+++ trunk/community/infrastructure/scripts/update-tasks	2008-03-01 14:09:12 UTC (rev 1492)
@@ -120,7 +120,7 @@
 	if deppkg.license != None:
 		node.license.content = "License: %s" % deppkg.license
 	# In case some '&' made it up to this place
-	node.pkgurl.atts['href'] = deppkg.pkgURL ## .replace("&", "%3F")
+	node.pkgurl.atts['href'] = deppkg.pkgURL ## .replace("&", "%26")
 	node.pkgurl.content = "Official Debian package"
 	node.deburl.atts['href'] = deppkg.filename
 	#~ node.deburl.content = "X" ### TODO: add a nice icon here to download the .deb package
@@ -145,7 +145,7 @@
 	node.url.content = deppkg.homepage
 	node.license.content = "License: %s" % deppkg.license
 	# In case some '&' made it up to this place
-	node.pkgurl.atts['href'] = deppkg.pkgURL ## .replace("&", "%3F")
+	node.pkgurl.atts['href'] = deppkg.pkgURL ## .replace("&", "%26")
 	node.pkgurl.content = "Unofficial Debian package"
 	if deppkg.responsible:
 		node.responsible.content = deppkg.responsible




More information about the debian-med-commit mailing list
--- trunk/community/infrastructure/scripts/cddtasktools.py	2008-03-01 14:02:29 UTC (rev 1491)
+++ trunk/community/infrastructure/scripts/cddtasktools.py	2008-03-01 14:09:12 UTC (rev 1492)
@@ -360,8 +360,8 @@
                               % stanza['wnpp']
                 elif key == 'Pkg-URL':
                     if dep != None:
-                	# Escape '&' in URLs with %3F (Trick stolen by pasting the URL into a search engine ;-))
-                        dep.pkgURL   = stanza['pkg-url'].replace("&", "%3F")
+                	# Escape '&' in URLs with %26 (Trick stolen by pasting the URL into a search engine ;-))
+                        dep.pkgURL   = stanza['pkg-url'].replace("&", "%26")
                     else:
                         print >>stderr, "Dep not initiated before Pkg-URL %s -> something is wrong." \
                               % stanza['pkg-url']

Modified: trunk/community/infrastructure/scripts/update-tasks
===================================================================